==> prismic_api-0.1.2.tar.gz: prismic_api-0.1.2/src/prismic/document.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Prismic API
# Copyright (c) 2008-2017 Hive Solutions Lda.
#
# This file is part of Hive Prismic API.
#
# Hive Prismic API is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Prismic API is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Prismic API. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

class DocumentAPI(object):

    def get_document(self, id):
        url = self.base_url + "documents/search"
        contents = self.get(
            url,
            q = "[[at(document.id,\"%s\")]]" % id
        )
        contents = self._decode(contents)
        results = contents["results"]
        return results[0] if results else None

    def search_documents(self, q = None, lang = "*"):
        url = self.base_url + "documents/search"
        contents = self.get(url, q = q, lang = lang)
        contents = self._decode(contents)
        results = contents["results"]
        return results

==> prismic_api-0.1.3.tar.gz: prismic_api-0.1.3/src/prismic/document.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Prismic API
# Copyright (c) 2008-2017 Hive Solutions Lda.
#
# This file is part of Hive Prismic API.
#
# Hive Prismic API is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Prismic API is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Prismic API. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

class DocumentAPI(object):

    def get_document(self, id):
        url = self.base_url + "documents/search"
        contents = self.get(
            url,
            q = "[[at(document.id,\"%s\")]]" % id
        )
        contents = self._decode(contents)
        results = contents["results"]
        return results[0] if results else None

    def search_documents(self, q = None, page_size = 10, lang = "*"):
        url = self.base_url + "documents/search"
        contents = self.get(
            url,
            q = q,
            pageSize = page_size,
            lang = lang
        )
        contents = self._decode(contents)
        results = contents["results"]
        return results
